@@ -11,8 +11,9 @@ config.db_plugin has to be configured first.
 		sys.exit(0)
 
 	try:
+		sys.path.insert(0, '.')
 		config = __import__('config')
 		config.db_plugin.droptables()
 	except ImportError:
-		sys.stderr.write("Can not find config.py. Is this a valid simpleweb project directory?\n")
+		sys.stderr.write("Could not successfully import config.py. Details follow:\n\t%s\n" % (e))
 
