@@ -1,4 +1,4 @@
-from pkg_resources import resource_filename, Requirement
+#from pkg_resources import resource_filename, Requirement
 import static
 import utils
 import plugins.auth
@@ -35,10 +35,4 @@ class AuthMiddleware(object):
 		return self.app(environ, start_response)
 
 
-class HTTPStatusMiddleWare(object):
-	def __init__(self, app):
-		self.app = app
-		self.status_register = {}
 
-	def __call__(self, environ, start_response):
-		self.app(environ, start_response)
