@@ -10,7 +10,7 @@ class SimpleAuth(object):
 	def __init__(self):
 		self.authuser_class = AuthUser
 
-	def authenticated(self, request, username, roles=[]):
+	def set_session_user(self, request, username, roles=[]):
 		user = AuthUser(username, roles)
 		request.session[simpleweb.utils.ENV_KEY_AUTH_MIDDLEWARE] = user
 
@@ -31,10 +31,15 @@ class SimpleAuth(object):
 				if request.session.user.username in users or filter(filter_inroles, request.session.user.roles):
 					return func(*args, **kw)
 				else:
-					return "Username or UserRole insufficient to access this resource!"
+					request.res.status = '401 Unauthorized'
+					request.res.headers['Content-type'] = 'text/html'
+					return """
+<h1>401 Unauthorized</h1>
 
-			#after decorating the methods, the names change from GET, POST, etc, to inner(), 
-			#this fixes that.
+<p>
+Username or UserRole not adequate to have access this resource!
+</p>
+"""
 
 			inner.__name__ = func.__name__
 			inner.__dict__ = func.__dict__
